@@ -261,7 +261,7 @@ def get_growth_factor_fin_data(code_list=['00700'], start_date=None, end_date=No
     __ = _all_fina_factor_handle_method(code_list, data_type, start_date, end_date, market, period)
     return __
 
-def get_debtPay_factor_fin_data(code_list=['00700'], start_date=None, end_date=None, market=2, period=12):
+def get_debtpay_factor_fin_data(code_list=['00700'], start_date=None, end_date=None, market=2, period=12):
     '''
         获取偿债能力因子数据
         Args:
@@ -280,7 +280,7 @@ def get_debtPay_factor_fin_data(code_list=['00700'], start_date=None, end_date=N
     __ = _all_fina_factor_handle_method(code_list, data_type, start_date, end_date, market, period)
     return __
 
-def get_baseFace_factor_fin_data(code_list=['00700'], start_date=None, end_date=None, market=2, period=12):
+def get_baseface_factor_fin_data(code_list=['00700'], start_date=None, end_date=None, market=2, period=12):
     '''
         获取一般基本面因子数据
         Args:
