@@ -244,7 +244,7 @@ def get_hbeta_factor_data(code_list=['00700'], market=2, unit='1d', start_date=N
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Hbeta', 'Trading_Day']
+    factor_names = ['secu_code', 'hbeta', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -264,7 +264,7 @@ def get_halpha_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Halpha', 'Trading_Day']
+    factor_names = ['secu_code', 'halpha', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -284,7 +284,7 @@ def get_hsigma_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Hsigma', 'Trading_Day']
+    factor_names = ['secu_code', 'hsigma', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -304,7 +304,7 @@ def get_hmsens_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Dmsens', 'Trading_Day']
+    factor_names = ['secu_code', 'dmsens', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -324,7 +324,7 @@ def get_oilsen_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Oilsen', 'Trading_Day']
+    factor_names = ['secu_code', 'oilsen', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -344,7 +344,7 @@ def get_dsbeta_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Dsbeta', 'Trading_Day']
+    factor_names = ['secu_code', 'dsbeta', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -364,7 +364,7 @@ def get_cmra_factor_data(code_list=['00700'], market=2, unit='1d', start_date=No
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Cmra', 'Trading_Day']
+    factor_names = ['secu_code', 'cmra', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -384,7 +384,7 @@ def get_stom_factor_data(code_list=['00700'], market=2, unit='1d', start_date=No
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Stom', 'Trading_Day']
+    factor_names = ['secu_code', 'stom', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -404,7 +404,7 @@ def get_stoq_factor_data(code_list=['00700'], market=2, unit='1d', start_date=No
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Stoq', 'Trading_Day']
+    factor_names = ['secu_code', 'Stoq', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -424,7 +424,7 @@ def get_stoa_factor_data(code_list=['00700'], market=2, unit='1d', start_date=No
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Stoa', 'Trading_Day']
+    factor_names = ['secu_code', 'stoa', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -444,7 +444,7 @@ def get_dastd_factor_data(code_list=['00700'], market=2, unit='1d', start_date=N
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['SecuCode', 'Dastd', 'Trading_Day']
+    factor_names = ['secu_code', 'dastd', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -464,7 +464,7 @@ def get_season_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
             fre:是否复权 默认不复权
         Returns: 返回因子数据
     '''
-    factor_names = ['SecuCode', 'Season', 'Trading_Day']
+    factor_names = ['secu_code', 'season', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
@@ -484,7 +484,7 @@ def get_rstr_factor_data(code_list=['00700'], market=2, unit='1d', start_date=No
             fre:是否复权 默认不复权
         Returns: 返回因子数据
     '''
-    factor_names = ['SecuCode', 'Rstr', 'Trading_Day']
+    factor_names = ['secu_code', 'rstr', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     #
@@ -505,7 +505,7 @@ def get_strev_factor_data(code_list=['00700'], market=2, unit='1d', start_date=N
             fre:是否复权 默认不复权
         Returns: 返回因子数据
     '''
-    factor_names = ['SecuCode', 'Strev', 'Trading_Day']
+    factor_names = ['secu_code', 'strev', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # if t_typeof(f_data_) == 'str':return f_data_
@@ -524,8 +524,8 @@ def total_cls_handle(code_list, factor_names, data_type=None, start_date=None, e
             return '您好, 检测到时间区间的存在问题, 导致取到的数据为空, 请修改时间后重新请求数据.'
 
         __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-    except:
-        __ = '您好, 检测到入参存在问题, 导致取到的数据为空, 请修改后重新请求数据.'
+    except Exception as xp:
+        __ = xp
     return __
 
 
